@@ -6,14 +6,30 @@ import (
 	"runtime/debug"
 	"strings"
 
-	"github.com/ProtonMail/gopenpgp/v2/constants"
+	"github.com/ProtonMail/gopenpgp/v3/constants"
 )
 
-const VERSION = "0.1.0"
+const VERSION = "1.1.0"
+const SOP_VERSION = "~draft-dkg-openpgp-stateless-cli-06"
+const SOPV_VERSION = "1.0"
 
 // Version prints version information about gosop, and/or the
 // underlying OpenPGP library/libraries.
 func Version() error {
+	if sopSpec {
+		_, err := os.Stdout.WriteString(SOP_VERSION + "\n")
+		if err != nil {
+			return versionErr(err)
+		}
+		return nil
+	}
+	if sopv {
+		_, err := os.Stdout.WriteString(SOPV_VERSION + "\n")
+		if err != nil {
+			return versionErr(err)
+		}
+		return nil
+	}
 	if !backend || extended {
 		_, err := os.Stdout.WriteString("gosop " + VERSION + "\n")
 		if err != nil {
